@@ -1,22 +1,25 @@
+"""Module provider for OnApp"""
 from __future__ import absolute_import
 import json
 import logging
 
 import requests
-from lexicon.providers.base import Provider as BaseProvider
 from requests.auth import HTTPBasicAuth
 
+from lexicon.providers.base import Provider as BaseProvider
+
 
 LOGGER = logging.getLogger(__name__)
 
 NAMESERVER_DOMAINS = []
 
 
-def ProviderParser(subparser):
+def provider_parser(subparser):
+    """Configure provider parser for OnApp"""
     subparser.description = '''
-        The OnApp provider requires your OnApp account\'s email address and 
+        The OnApp provider requires your OnApp account\'s email address and
         API token, which can be found on your /profile page on the Control Panel interface.
-        The server is your dashboard URL, in the format of e.g. https://dashboard.youronapphost.org'''
+        The server is your dashboard URL, with format like https://dashboard.youronapphost.org'''
     subparser.add_argument(
         '--auth-username', help='specify email address of the OnApp account')
     subparser.add_argument(
@@ -26,7 +29,7 @@ def ProviderParser(subparser):
 
 
 class Provider(BaseProvider):
-
+    """Provider class for OnApp"""
     def __init__(self, config):
         super(Provider, self).__init__(config)
 
@@ -41,7 +44,7 @@ class Provider(BaseProvider):
 
         self.session = requests.Session()
 
-    def authenticate(self):
+    def _authenticate(self):
         domain = self.domain
 
         zones = self._get('/dns_zones.json')
@@ -54,11 +57,11 @@ class Provider(BaseProvider):
             raise Exception(
                 'Could not find {0} in OnApp DNS Zones'.format(domain))
 
-    def create_record(self, type, name, content):
+    def _create_record(self, rtype, name, content):
         data = {
             'name': self._relative_name(name),
-            'type': type,
-            self._key_for_record_type(type): content
+            'type': rtype,
+            self._key_for_record_type(rtype): content
         }
 
         ttl = self._get_lexicon_option('ttl')
@@ -71,28 +74,29 @@ class Provider(BaseProvider):
 
         return True
 
-    def list_records(self, type=None, name=None, content=None):
+    def _list_records(self, rtype=None, name=None, content=None):
         records = []
 
         response = self._get(
             '/dns_zones/{0}/records.json'.format(self.domain_id))
-        for recordType in response['dns_zone']['records']:
+        for record_type in response['dns_zone']['records']:
 
-            # For now we do not support other RR types so we ignore them, also see _key_for_record_type
-            if recordType not in ('A', 'AAAA', 'CNAME', 'TXT'):
+            # For now we do not support other RR types so we ignore them, also see
+            # _key_for_record_type
+            if record_type not in ('A', 'AAAA', 'CNAME', 'TXT'):
                 continue
 
-            if type and recordType != type:
+            if rtype and record_type != rtype:
                 continue
 
-            for record in response['dns_zone']['records'][recordType]:
+            for record in response['dns_zone']['records'][record_type]:
                 record = record['dns_record']
 
                 if name and record['name'] != self._relative_name(name):
                     continue
 
-                recordContent = record[self._key_for_record_type(recordType)]
-                if content and recordContent != content:
+                record_content = record[self._key_for_record_type(record_type)]
+                if content and record_content != content:
                     continue
 
                 records.append({
@@ -100,16 +104,16 @@ class Provider(BaseProvider):
                     'name': self._full_name(record['name']),
                     'type': record['type'],
                     'ttl': record['ttl'],
-                    'content': recordContent
+                    'content': record_content
                 })
 
         LOGGER.debug('list_records: %s', records)
 
         return records
 
-    def update_record(self, identifier, type=None, name=None, content=None):
+    def _update_record(self, identifier, rtype=None, name=None, content=None):
         if not identifier:
-            existing = self._guess_record(type, name)
+            existing = self._guess_record(rtype, name)
             identifier = existing['id']
 
         ttl = self._get_lexicon_option('ttl')
@@ -126,7 +130,7 @@ class Provider(BaseProvider):
         request = {
             'name': self._relative_name(name),
             'ttl': '{0}'.format(ttl),
-            self._key_for_record_type(type): content
+            self._key_for_record_type(rtype): content
         }
 
         result = self._put('/dns_zones/{0}/records/{1}.json'.format(
@@ -135,18 +139,18 @@ class Provider(BaseProvider):
 
         return True
 
-    def delete_record(self, identifier=None, type=None, name=None, content=None):
+    def _delete_record(self, identifier=None, rtype=None, name=None, content=None):
         deletion_ids = []
 
         if not identifier:
-            records = self.list_records(type, name, content)
+            records = self._list_records(rtype, name, content)
             deletion_ids = [record['id'] for record in records]
         else:
             deletion_ids.append(identifier)
 
-        for id in deletion_ids:
+        for one_id in deletion_ids:
             self._delete(
-                '/dns_zones/{0}/records/{1}.json'.format(self.domain_id, id))
+                '/dns_zones/{0}/records/{1}.json'.format(self.domain_id, one_id))
 
         LOGGER.debug('delete_record: %s', True)
 
@@ -175,27 +179,30 @@ class Provider(BaseProvider):
 
         if result.text:
             return result.json()
-        else:
-            return None
+        return None
 
-    def _key_for_record_type(self, record_type):
+    def _key_for_record_type(self, record_type):  # pylint: disable=no-self-use
         if record_type in ('A', 'AAAA'):
             return 'ip'
-        elif record_type == 'CNAME':
+        if record_type == 'CNAME':
             return 'hostname'
-        elif record_type == 'TXT':
+        if record_type == 'TXT':
             return 'txt'
-        elif record_type in ('MX', 'NS', 'SOA', 'SRV', 'LOC'):
+        if record_type in ('MX', 'NS', 'SOA', 'SRV', 'LOC'):
             raise Exception(
                 '{0} record type is not supported in the OnApp Provider'.format(record_type))
+        raise Exception(
+            '{0} record type is unknown'.format(record_type))
 
-    def _guess_record(self, type, name=None, content=None):
-        records = self.list_records(type=type, name=name, content=content)
+    def _guess_record(self, rtype, name=None, content=None):
+        records = self._list_records(rtype=rtype, name=name, content=content)
         if len(records) == 1:
             return records[0]
-        elif len(records) > 1:
+        if len(records) > 1:
             raise Exception(
-                'Identifier was not provided and several existing records match the request for {0}/{1}'.format(type, name))
-        elif len(records) == 0:
+                'Identifier was not provided and several existing records '
+                'match the request for {0}/{1}'.format(rtype, name))
+        else:
             raise Exception(
-                'Identifier was not provided and no existing records match the request for {0}/{1}'.format(type, name))
+                'Identifier was not provided and no existing records '
+                'match the request for {0}/{1}'.format(rtype, name))
