@@ -1,5 +1,4 @@
 """Rackspace provider implementation"""
-
 from __future__ import absolute_import
 import json
 import logging
@@ -23,28 +22,34 @@ def _async_request_completed(payload):
     return False
 
 
-def ProviderParser(subparser):
+def provider_parser(subparser):
+    """Configure provider parser for Rackspace"""
     subparser.add_argument(
         "--auth-account", help="specify account number for authentication")
     subparser.add_argument(
-        "--auth-username", help="specify username for authentication. Only used if --auth-token is empty.")
+        "--auth-username",
+        help="specify username for authentication. Only used if --auth-token is empty.")
     subparser.add_argument(
-        "--auth-api-key", help="specify api key for authentication. Only used if --auth-token is empty.")
+        "--auth-api-key",
+        help="specify api key for authentication. Only used if --auth-token is empty.")
     subparser.add_argument(
-        "--auth-token", help="specify token for authentication. If empty, the username and api key will be used to create a token.")
+        "--auth-token",
+        help=("specify token for authentication. "
+              "If empty, the username and api key will be used to create a token."))
     subparser.add_argument("--sleep-time", type=float, default=1,
                            help="number of seconds to wait between update requests.")
 
 
 class Provider(BaseProvider):
-
+    """Provider class for Rackspace"""
     def __init__(self, config):
         super(Provider, self).__init__(config)
         self.domain_id = None
         self.api_endpoint = 'https://dns.api.rackspacecloud.com/v1.0'
         self.auth_api_endpoint = 'https://identity.api.rackspacecloud.com/v2.0'
+        self._auth_token = None
 
-    def authenticate(self):
+    def _authenticate(self):
         self._auth_token = self._get_provider_option('auth_token')
         if not self._auth_token:
             auth_response = self._auth_request('POST', '/tokens', {
@@ -70,19 +75,19 @@ class Provider(BaseProvider):
 
     # Create record. If record already exists with the same content, do nothing'
 
-    def create_record(self, type, name, content):
+    def _create_record(self, rtype, name, content):
         data = {'records': [
-            {'type': type, 'name': self._full_name(name), 'data': content}]}
+            {'type': rtype, 'name': self._full_name(name), 'data': content}]}
         if self._get_lexicon_option('ttl'):
             data['records'][0]['ttl'] = self._get_lexicon_option('ttl')
 
         try:
             payload = self._post_and_wait(
                 '/domains/{0}/records'.format(self.domain_id), data)
-        except Exception as e:
-            if str(e).startswith('Record is a duplicate of another record'):
-                return self.update_record(None, type, name, content)
-            raise e
+        except Exception as error:
+            if str(error).startswith('Record is a duplicate of another record'):
+                return self._update_record(None, rtype, name, content)
+            raise error
 
         success = len(payload['records']) > 0
         LOGGER.debug('create_record: %s', success)
@@ -91,10 +96,10 @@ class Provider(BaseProvider):
     # List all records. Return an empty list if no records found
     # type, name and content are used to filter records.
     # If possible filter during the query, otherwise filter after response is received.
-    def list_records(self, type=None, name=None, content=None):
+    def _list_records(self, rtype=None, name=None, content=None):
         params = {'per_page': 100}
-        if type:
-            params['type'] = type
+        if rtype:
+            params['type'] = rtype
         if name:
             params['name'] = self._full_name(name)
         # Sending the data filter to the Rackspace DNS API results in a 503 error
@@ -120,10 +125,10 @@ class Provider(BaseProvider):
         return records
 
     # Create or update a record.
-    def update_record(self, identifier, type=None, name=None, content=None):
+    def _update_record(self, identifier, rtype=None, name=None, content=None):
         data = {}
-        if type:
-            data['type'] = type
+        if rtype:
+            data['type'] = rtype
         if name:
             data['name'] = self._full_name(name)
         if content:
@@ -132,8 +137,8 @@ class Provider(BaseProvider):
             data['ttl'] = self._get_lexicon_option('ttl')
 
         if identifier is None:
-            records = self.list_records(type, name)
-            if len(records) < 1:
+            records = self._list_records(rtype, name)
+            if not records:
                 raise Exception('Unable to find record to modify: ' + name)
             identifier = records[0]['id']
 
@@ -146,10 +151,10 @@ class Provider(BaseProvider):
 
     # Delete an existing record.
     # If record does not exist, do nothing.
-    def delete_record(self, identifier=None, type=None, name=None, content=None):
+    def _delete_record(self, identifier=None, rtype=None, name=None, content=None):
         delete_record_id = []
         if not identifier:
-            records = self.list_records(type, name, content)
+            records = self._list_records(rtype, name, content)
             delete_record_id = [record['id'] for record in records]
         else:
             delete_record_id.append(identifier)
@@ -157,7 +162,7 @@ class Provider(BaseProvider):
         LOGGER.debug('delete_records: %s', delete_record_id)
 
         for record_id in delete_record_id:
-            payload = self._delete_and_wait(
+            self._delete_and_wait(
                 '/domains/{0}/records/{1}'.format(self.domain_id, record_id)
             )
 
@@ -175,15 +180,15 @@ class Provider(BaseProvider):
             query_params = {}
         full_url = (self.api_endpoint +
                     '/{0}' + url).format(self._get_provider_option('auth_account'))
-        r = requests.request(action, full_url, params=query_params,
-                             data=json.dumps(data),
-                             headers={
-                                 'X-Auth-Token': self._get_provider_option('auth_token'),
-                                 'Content-Type': 'application/json'
-                             })
+        response = requests.request(action, full_url, params=query_params,
+                                    data=json.dumps(data),
+                                    headers={
+                                        'X-Auth-Token': self._get_provider_option('auth_token'),
+                                        'Content-Type': 'application/json'
+                                    })
         # if the request fails for any reason, throw an error.
-        r.raise_for_status()
-        return r.json()
+        response.raise_for_status()
+        return response.json()
 
     # Non-GET requests to the Rackspace CloudDNS API are asynchronous
     def _request_and_wait(self, action='POST', url='/', data=None, query_params=None):
@@ -214,26 +219,25 @@ class Provider(BaseProvider):
         return self._request_and_wait('DELETE', url, data, query_params)
 
     def _update_response(self, payload):
-        r = requests.request('GET', payload['callbackUrl'], params={'showDetails': 'true'},
-                             data={},
-                             headers={
-                                 'X-Auth-Token': self._get_provider_option('auth_token'),
-                                 'Content-Type': 'application/json'
-        })
+        response = requests.request('GET', payload['callbackUrl'], params={'showDetails': 'true'},
+                                    data={},
+                                    headers={
+                                        'X-Auth-Token': self._get_provider_option('auth_token'),
+                                        'Content-Type': 'application/json'})
 
         # if the request fails for any reason, throw an error.
-        r.raise_for_status()
-        return r.json()
+        response.raise_for_status()
+        return response.json()
 
     def _auth_request(self, action='GET', url='/', data=None, query_params=None):
         if data is None:
             data = {}
 
-        r = requests.request(action, self.auth_api_endpoint + url, params=query_params,
-                             data=json.dumps(data),
-                             headers={
-                                 'Content-Type': 'application/json'
-                             })
+        response = requests.request(action, self.auth_api_endpoint + url, params=query_params,
+                                    data=json.dumps(data),
+                                    headers={
+                                        'Content-Type': 'application/json'
+                                    })
         # if the request fails for any reason, throw an error.
-        r.raise_for_status()
-        return r.json()
+        response.raise_for_status()
+        return response.json()
